### These are the graphics routines for Cenbe's Disk Wrangler, an explorer for Commodore 64 disk images written in Python and Qt.

They were split off into a separate project so that programmers wanting
to use the d64py library for text-based programs wouldn't need to
import all of the Qt libraries as well.
